@@ -1,4 +1,7 @@
-from gevault.lib.vault import Vault
+try:
+    from gevault.lib.vault import Vault
+except ModuleNotFoundError:
+    from lib.vault import Vault
 
 class Users(Vault):
 
